@@ -1,8 +1,9 @@
-// AluRE: AluVM runtime environment.
-// This is rust implementation of AluVM (arithmetic logic unit virtual machine).
+// Reference rust implementation of AluVM (arithmetic logic unit virtual machine).
+// To find more on AluVM please check <https://github.com/internet2-org/aluvm-spec>
 //
 // Designed & written in 2021 by
 //     Dr. Maxim Orlovsky <orlovsky@pandoracore.com>
+// This work is donated to LNP/BP Standards Association by Pandora Core AG
 //
 // This software is licensed under the terms of MIT License.
 // You should have received a copy of the MIT License along with this software.
@@ -10,18 +11,20 @@
 
 #[macro_use]
 mod asm;
-pub mod bytecode;
+mod bitcode;
 mod exec;
-#[allow(clippy::module_inception)]
-mod instr;
-mod op_codes;
-mod op_types;
+mod flags;
+mod opcode;
+pub mod serialize;
 
-pub use bytecode::Bytecode;
+pub use bitcode::*;
 pub use exec::{ExecStep, InstructionSet};
-pub use instr::*;
-pub use op_codes::{
+pub use flags::{
+    DeleteFlag, FloatEqFlag, InsertFlag, IntFlags, MergeFlag, ParseFlagError, RoundingFlag,
+    SignFlag, SplitFlag,
+};
+pub use opcode::{
     ArithmeticOp, BitwiseOp, BytesOp, CmpOp, ControlFlowOp, Curve25519Op, DigestOp, Instr, MoveOp,
     NOp, PutOp, Secp256k1Op,
 };
-pub use op_types::{Arithmetics, IncDec, NumType};
+pub use serialize::Bytecode;
